<!-- markdownlint-disable -->

<a href="..\..\qtstrap\widgets\link_label.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `widgets.link_label`




**Global Variables**
---------------
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**


---

<a href="..\..\qtstrap\widgets\link_label.py#L4"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `LinkLabel`




<a href="..\..\qtstrap\widgets\link_label.py#L5"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LinkLabel.__init__`

```python
__init__(text='', link='', both=None, parent=None)
```








---

<a href="..\..\qtstrap\widgets\link_label.py#L24"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LinkLabel.setLink`

```python
setLink(link)
```





---

<a href="..\..\qtstrap\widgets\link_label.py#L20"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LinkLabel.setText`

```python
setText(text)
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
